@@ -1,5 +1,5 @@
 package Linux::FD::Event;
-$Linux::FD::Event::VERSION = '0.010';
+$Linux::FD::Event::VERSION = '0.012';
 use 5.006;
 
 use strict;
@@ -22,7 +22,7 @@ Linux::FD::Event - Event filehandles for Linux
 
 =head1 VERSION
 
-version 0.010
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -36,11 +36,15 @@ version 0.010
      $foo->add($_) while <>;
  }
 
+=head1 DESCRIPTION
+
+This creates an eventfd object that can be used as an event wait/notify mechanism by userspace applications, and by the kernel to notify userspace applications of events. The object contains an unsigned 64-bit integer counter that is maintained by the kernel. It has two modes, default and semaphore, that differ only in C<get> behavior as described below.
+
 =head1 METHODS
 
 =head2 new($initial_value, @flags)
 
-This creates an eventfd object that can be used as an event wait/notify mechanism by userspace applications, and by the kernel to notify userspace applications of events. The object contains an unsigned 64-bit integer counter that is maintained by the kernel. This counter is initialized with the value specified in the argument C<$initial_value>. C<@flags> is an optional list of flags, currently limited to C<'non-blocking'> (requires Linux 2.6.27), and C<'semaphore'> (requires Linux 2.6.30).
+This creates a new eventfd filehandler. The counter is initialized with the value specified in the argument C<$initial_value>. C<@flags> is an optional list of flags, currently limited to C<'non-blocking'> (requires Linux 2.6.27), and C<'semaphore'> (requires Linux 2.6.30).
 
 =head2 get()
 
