@@ -1,5 +1,5 @@
 package Linux::FD::Timer;
-$Linux::FD::Timer::VERSION = '0.010';
+$Linux::FD::Timer::VERSION = '0.012';
 use 5.006;
 
 use strict;
@@ -22,13 +22,13 @@ Linux::FD::Timer - Timer filehandles for Linux
 
 =head1 VERSION
 
-version 0.010
+version 0.012
 
 =head1 SYNOPSIS
 
  use Linux::FD::Timer;
 
- my $fh = Linux::FD::Timer->new('monotonic');
+ my $fh = Linux::FD::Timer->new('monotonic', @flags);
  $fh->set_timeout(10, 10);
  while (1) {
      #do something..
@@ -43,7 +43,7 @@ This module creates and operates on a timer that delivers timer expiration notif
 
 =head2 new($clockid)
 
-This creates a new timer object, and returns a file handle that refers to that timer. The clockid argument specifies the clock that is used to mark the progress of the timer, and must be either C<'realtime'> or C<'monotonic'>. C<realtime> is a settable system-wide clock. C<monotonic> is a non-settable clock that is not affected by discontinuous changes in the system clock (e.g., manual changes to system time). The current value of each of these clocks can be retrieved using L<POSIX::RT::Clock>.
+This creates a new timer object, and returns a file handle that refers to that timer. The clockid argument specifies the clock that is used to mark the progress of the timer, and must be either C<'realtime'> or C<'monotonic'>. C<realtime> is a settable system-wide clock. C<monotonic> is a non-settable clock that is not affected by discontinuous changes in the system clock (e.g., manual changes to system time). The current value of each of these clocks can be retrieved using L<POSIX::RT::Clock>. C<@flags> is an optional list of flags, currently limited to C<'non-blocking'> (requires Linux 2.6.27).
 
 =head2 get_timeout()
 
@@ -57,6 +57,10 @@ Set the timer and interval values. If C<$abstime> is true, they are absolute val
 
 If the timer has already expired one or more times since its settings were last modified using settime(), or since the last successful wait, then receive returns an unsigned 64-bit integer containing the number of expirations that have occurred. If not it either returns undef or it blocks (if the handle is blocking).
 
+=head2 clocks
+
+This returns a list of all known clocks usable in a timerfd. Do note that some clocks may require superuser privileges.
+
 =head1 AUTHOR
 
 Leon Timmermans <leont@cpan.org>
